@@ -32,7 +32,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.49';
+our $VERSION = '2.50';
 
 =head1 SYNOPSIS
 
@@ -133,25 +133,6 @@ has 'module' => (
     default => sub {[]},
 );
 
-=head2 jobname
-
-Specify a job name, and jobs will be jobname_1, jobname_2, jobname_x
-
-=cut
-
-has 'jobname' => (
-    is => 'rw',
-    isa => 'Str',
-    required => 0,
-    traits  => ['String'],
-    default => q{job},
-    handles => {
-        add_jobname => 'append',
-        clear_jobname => 'clear',
-        replace_jobname => 'replace',
-    },
-    documentation => q{Specify a job name, each job will be appended with its batch order},
-);
 
 =head2 afterok
 
